@@ -1,6 +1,7 @@
 """
 fastools: Various tools for the analysis and manipulation of FASTA/FASTQ files.
 
+
 Copyright (c) 2013 Leiden University Medical Center <humgen@lumc.nl>
 Copyright (c) 2013 Jeroen F.J. Laros <j.f.j.laros@lumc.nl>
 
@@ -22,7 +23,7 @@ Licensed under the MIT license, see the LICENSE file.
 
 RELEASE = False
 
-__version_info__ = ('0', '4', 'dev')
+__version_info__ = ('0', '5', 'dev')
 
 
 __version__ = '.'.join(__version_info__)
@@ -30,9 +31,11 @@ __author__ = 'LUMC, Jeroen F.J. Laros'
 __contact__ = 'j.f.j.laros@lumc.nl'
 __homepage__ = 'https://humgenprojects.lumc.nl/svn/fastools'
 
+usage = __doc__.split("\n\n\n")
+
 def docSplit(func):
     return func.__doc__.split("\n\n")[0]
 
 def version(name):
-    return "%s version %s\n%s\n%s\n%s" % (name, __version__, __author__,
-        __contact__, __homepage__)
+    return "%s version %s\n\nAuthor   : %s <%s>\nHomepage : %s" % (name,
+        __version__, __author__, __contact__, __homepage__)
